import Batch from '../dtos/batch';
import apiClient from './api-client';

const endpoint = 'batches';

const fetchById = async (id, params) => {
  if (!id) throw new Error('id is required');

  let response = await apiClient.get(`${endpoint}/${id}`, params);
  if (response.ok) {
    response.data = new Batch(response.data);
  }

  return response;
};

const fetchList = async (params) => {
  let response = await apiClient.get(endpoint, params);
  let batches = [];

  if (response.ok) {
    response.data.forEach((recipeData) => {
      batches.push(new Batch(recipeData));
    });
    response.data = batches;
  }

  return response;
};

const addDeviceToBatch = (id, deviceId, params) => {
  return apiClient.patch(`${endpoint}/${id}/add-device`, { deviceId }, params);
};

const removeDeviceFromBatch = (id, deviceId, params) => {
  return apiClient.patch(`${endpoint}/${id}/remove-device`, { deviceId }, params);
};

const create = (batchData, params) => {
  return apiClient.post(endpoint, batchData, params);
};

const edit = (id, data, params) => {
  return apiClient.patch(`${endpoint}/${id}`, data, params);
};

const addFeedback = (batchId, data, params) => {
  return apiClient.post(`${endpoint}/${batchId}/feedback`, data, params);
};

const remove = (batchId, params) => {
  return apiClient.delete(`${endpoint}/${batchId}`, params);
};

const getStatus = (batchId, params) => {
  return apiClient.get(`${endpoint}/${batchId}/status`, params);
};

const addOrUpdateOG = (id, data, params) => {
  return apiClient.post(`${endpoint}/${id}/og`, data, params);
};

const endBatch = (id, data, params) => {
  return apiClient.post(`${endpoint}/${id}/end`, data, params);
};

const adjustBatch = (id, data, params) => {
  return apiClient.patch(`${endpoint}/${id}/adjust`, data, params);
};
export default {
  fetchById,
  fetchList,
  create,
  addDeviceToBatch,
  removeDeviceFromBatch,
  edit,
  addFeedback,
  remove,
  getStatus,
  addOrUpdateOG,
  endBatch,
  adjustBatch,
};
