import Client from "../dtos/client";
import apiClient from "./api-client";

const endpoint = 'clients';
const adminEndpoint = 'admin/clients';

const fetchById = async (id, params) => {
  if (!id) throw new Error('id is required');

  let response = await apiClient.get(`${endpoint}/${id}`, params);
  if (response.ok) {
    response.data = new Client(response.data);
  }

  return response;
}

const create = (data, params) => {
  return apiClient.post(endpoint, data, params);
};

const edit = (id, data, params) => {
  return apiClient.patch(`${endpoint}/${id}`, data, params);
};

const adminEdit = (id,route, data, params) => {
  return apiClient.patch(`${adminEndpoint}/${id}/${route}`, data, params);
};

const fetchList = async (params) => {
  let response = await apiClient.get(endpoint, params);
  let recipes = [];

  if (response.ok) {
    response.data.forEach(recipeData => {
      recipes.push(new Client(recipeData));
    });
    response.data = recipes;
  }

  return response;
}

const fetchAdminList = async (params) => {
  let response = await apiClient.get(adminEndpoint, params);
  let recipes = [];

  if (response.ok) {
    response.data.forEach(recipeData => {
      recipes.push(new Client(recipeData));
    });
    response.data = recipes;
  }

  return response;
}

const updatePreferences = async (id, data) => {
  return apiClient.patch(`${endpoint}/${id}/preferences`, data);
}


export default {
  fetchById,
  fetchList,
  fetchAdminList,
  adminEdit,
  create,
  edit,
  updatePreferences
};