import Device from '../dtos/device';
import apiClient from './api-client';

const endpoint = '/devices';
const adminEndpoint = '/admin/clients';
const deviceAdminEndpoint = '/admin/devices';

const addDeviceToClient = (hardwareId, clientId, params) => {
  return apiClient.patch(`${endpoint}/${hardwareId}/add-client`, { clientId }, params);
};

const removeDeviceFromClient = (deviceId, params) => {
  return apiClient.delete(`${endpoint}/${deviceId}`, params);
};

const edit = (id, deviceData, params) => {
  return apiClient.patch(`${endpoint}/${id}`, deviceData, params);
};

const archiveDevice = (id, params) => {
  return apiClient.post(`${endpoint}/archive/${id}`, params);
};

const fetchById = async (id, params) => {
  if (!id) throw new Error('id is required');

  let response = await apiClient.get(`${endpoint}/${id}`, params);
  if (response.ok) {
    response.data = new Device(response.data);
  }

  return response;
};

const fetchList = (params) => {
  let response = apiClient.get(endpoint, params);
  let devices = [];

  if (response.ok) {
    response.data.forEach((deviceData) => {
      devices.push(new Device(deviceData));
    });
    response.data = devices;
  }

  return response;
};

const fetchAdminList = async (clientId, params) => {
  let response = await apiClient.get(`${adminEndpoint}/${clientId}/devices`, params);
  let devices = [];

  if (response.ok) {
    response.data.forEach((device) => {
      devices.push(new Device(device));
    });
    response.data = devices;
  }

  return response;
};

const getDeviceByCode = (barcode, params) => {
  return apiClient.get(`${endpoint}/barcode/${barcode}`, params);
};

const getDeviceSleepTime = async (id, params) => {
  return await apiClient.get(`${endpoint}/${id}/sleep-time`, params);
};

const updateDeviceSleepTime = async (id, params) => {
  return await apiClient.patch(`${endpoint}/${id}/sleep-time`, params);
};

const updateUnderInvestigation = async (id, params) => {
  return await apiClient.patch(`${deviceAdminEndpoint}/${id}/under-investigation`, params);
};

export default {
  fetchList,
  fetchAdminList,
  fetchById,
  archiveDevice,
  addDeviceToClient,
  edit,
  getDeviceByCode,
  removeDeviceFromClient,
  getDeviceSleepTime,
  updateDeviceSleepTime,
  updateUnderInvestigation,
};
