import Fermentable from "../dtos/fermentable";
import apiClient from "./api-client";

const endpoint = 'fermentables';

const fetchById = async (id, params) => {
  if (!id) throw new Error('id is required');

  let response = await apiClient.get(`${endpoint}/${id}`, params);
  if (response.ok) {
    response.data = new Fermentable(response.data);
  }

  return response;
}

const fetchList = async (params) => {
  let response = await apiClient.get(endpoint, params);
  let fermentables = [];

  if (response.ok) {
    response.data.forEach(fermentableData => {
      fermentables.push(new Fermentable(fermentableData));
    });
    response.data = fermentables;
  }

  return response;
}

const create = (data, params) => {
  return apiClient.post(endpoint, data, params);
};

const edit = (id, data, params) => {
  return apiClient.patch(`${endpoint}/${id}`, data, params);
};

const remove = (fermentableId, params) => {
  return apiClient.delete(`${endpoint}/${fermentableId}`, params);
};

export default {
  fetchById,
  fetchList,
  create,
  edit,
  remove
};

