import Recipe from "../dtos/recipe";
import apiClient from "./api-client";

const endpoint = 'recipes';

const fetchById = async (id, params) => {
  if (!id) throw new Error('id is required');

  let response = await apiClient.get(`${endpoint}/${id}`, params);
  if (response.ok) {
    response.data = new Recipe(response.data);
  }

  return response;
}

const fetchList = async (params) => {
  let response = await apiClient.get(endpoint, params);
  let recipes = [];

  if (response.ok) {
    response.data.forEach(recipeData => {
      recipes.push(new Recipe(recipeData));
    });
    response.data = recipes;
  }

  return response;
}

const create = (recipeData) => {
  return apiClient.post(endpoint, recipeData);
};

const edit = (id, data, params) => {
  return apiClient.patch(`${endpoint}/${id}`, data, params);
};

const remove = (recipeId) => {
  return apiClient.delete(`${endpoint}/${recipeId}`);
};

const listBatchByRecipeId = (recipeId) => {
  return apiClient.get(`${endpoint}/${recipeId}/batches`);
}

export default {
  fetchById,
  fetchList,
  create,
  edit,
  remove,
  listBatchByRecipeId
};

