import User from '../dtos/user';
import apiClient from './api-client';

const endpoint = '/users';
const adminEndpoint = '/admin/clients';
const fetchById = async (id, params) => {
  if (!id) throw new Error('id is required');

  let response = await apiClient.get(`${endpoint}/${id}`, params);
  if (response.ok) {
    response.data = new User(response.data);
  }

  return response;
};

const fetchList = async (params) => {
  let response = await apiClient.get(endpoint, params);
  let users = [];

  if (response.ok) {
    response.data.forEach((recipeData) => {
      users.push(new User(recipeData));
    });
    response.data = users;
  }

  return response;
};

const fetchAdminList = async (clientId, params) => {
  let response = await apiClient.get(`${adminEndpoint}/${clientId}/users`, params);
  let users = [];

  if (response.ok) {
    response.data.forEach(userData => {
      users.push(new User(userData));
    });
    response.data = users;
  }

  return response;
}

const register = (userInfo) => apiClient.post(endpoint, userInfo);

const addUserToClient = (userId, clientId) => {
  return apiClient.patch(`${endpoint}/${userId}`, { clientId });
};

const updateUserPreferences = (user, body) => {
  return apiClient.patch(`${endpoint}/${user.id}`, body);
};

const appUsage = (body) => {
  return apiClient.post(`${endpoint}/usage/mobileapp`, body);
};

const appUsageWebapp = (body) => {
  return apiClient.post(`${endpoint}/usage/webapp`, body);
};

export default {
  fetchById,
  fetchList,
  register,
  fetchAdminList,
  addUserToClient,
  appUsage,
  appUsageWebapp,
  updateUserPreferences,
};
