import constants from './constants';

const PSI2BAR = 0.0689475;

function usePressureUtils() {
  let unit;

  const setPressureUnit = (newUnit) => {
    if (![constants.PSI, constants.BAR].includes(newUnit)) {
      throw new Error(`Pressure unit not recognised: ${newUnit}`)
    } else {
      unit = newUnit
    }
  }

  const getPressure = (psi) => {
    switch (unit) {
      case constants.PSI:
        return parseFloat(psi).toFixed(1);
      case constants.BAR:
        return convertPsiToBar(psi).toFixed(2);
      default:
        return undefined
    }
  }

  const getPressureString = (psi, withUnit = true) => {
    if (!Number.isFinite(psi)) return '--';

    let pressure = getPressure(psi);
    if (withUnit) pressure += ` ${getPressureUnit()}`;

    return pressure;
  }

  function convertPsiToBar(psi) {
    return psi * PSI2BAR;
  }

  const convertBarToPsi = (bar) => {
    return bar / PSI2BAR;
  }

  const getPressureUnit = () => {
    return unit;
  }

  const getPSI = (pressure) => {
    const cleaned = pressure.toString().replace(/,/, '.');
    const pressureNumber = parseFloat(cleaned)

    switch (unit) {
      case constants.PSI:
        return pressureNumber
      case constants.BAR:
        return convertBarToPsi(pressureNumber)
      default:
        return undefined
    }
  }

  return {
    setPressureUnit,
    getPSI,
    getPressure,
    getPressureString,
    getPressureUnit,
  };
}

export default usePressureUtils;