import constants from './constants';

function useTemperatureUtils() {
  let unit;

  const setTemperatureUnit = (newUnit) => {
    if (![constants.CELSIUS, constants.FAHRENHEIT].includes(newUnit)) {
      throw new Error(`Temperature unit not recognised: ${newUnit}`)
    } else {
      unit = newUnit
    }
  }

  const getTemperature = (celsius) => {
    switch (unit) {
      case constants.CELSIUS:
        return parseFloat(celsius);
      case constants.FAHRENHEIT:
        return convertCelsiusToFahrenheit(celsius);
      default:
        return undefined
    }
  }

  const getTemperatureUnit = () => {
    switch (unit) {
      case constants.CELSIUS:
        return '°C';
      case constants.FAHRENHEIT:
        return '°F';
      default:
        return undefined
    }
  }

  const getTemperatureString = (celsius, withUnit = true) => {
    const temperature = getTemperature(celsius);
    if (!Number.isFinite(temperature)) return '--';

    let result = temperature.toFixed(1);
    if (withUnit) result += ` ${getTemperatureUnit()}`;

    return result;
  }

  function convertCelsiusToFahrenheit(celsius) {
    if(!celsius) return celsius;
    const fahrenheit = celsius * 9 / 5 + 32;
    return Math.round(fahrenheit * 100) / 100;
  }

  const convertFahrenheitToCelsius = (fahrenheit) => {
    // TODO: implement
    return fahrenheit;
  }

  const getTemperatureMin = () => {
    // TODO: set these to plaato constants
    return 0;
  }

  const getTemperatureMax = () => {
    // TODO: set these to plaato constants
    return 9;
  }

  return {
    setTemperatureUnit,
    getTemperature,
    getTemperatureMin,
    getTemperatureMax,
    getTemperatureString,
    getTemperatureUnit,
  };
}

export default useTemperatureUtils;